@@ -10,7 +10,9 @@ __all__ = [
     "contour",
     "dumbbell_plot",
     "ridge",
-    "parallel_coordinates"
+    "parallel_coordinates",
+    "lollipop_plot",
+    "circular_bar_plot",
 ]
 
 import random
@@ -418,7 +420,7 @@ def imshow(
         >>> from easy_mpl import imshow
         >>> x = np.random.random((10, 5))
         >>> imshow(x, annotate=True)
-        # show colorbar
+        ... # show colorbar
         >>> imshow(x, colorbar=True)
 
     .. _axes.imshow:
@@ -562,7 +564,7 @@ def pie(
         >>> pie(np.random.randint(0, 3, 100))
         or by directly providing fractions
         >>> pie([0.2, 0.3, 0.1, 0.4])
-        # to explode 0.3
+        ... # to explode 0.3
         >>> explode = (0, 0.1, 0, 0, 0)
         >>> pie(fractions=[0.2, 0.3, 0.15, 0.25, 0.1], explode=explode)
 
@@ -641,9 +643,9 @@ def scatter(
         >>> x_ = np.random.random(100)
         >>> y_ = np.random.random(100)
         >>> scatter(x_, y_, show=False)
-        show colorbar
+        ... show colorbar
         >>> scatter(x_, y_, colorbar=True, show=False)
-        retrieve axes for further processing
+        ... retrieve axes for further processing
         >>> axes, _ = scatter(x_, y_, show=False)
         >>> assert isinstance(axes, plt.Axes)
 
@@ -735,7 +737,7 @@ def contour(
         >>> _y = np.random.uniform(-2, 2, 200)
         >>> _z = _x * np.exp(-_x**2 - _y**2)
         >>> contour(_x, _y, _z, fill_between=True, show_points=True)
-        show contour labels
+        ... show contour labels
         >>> contour(_x, _y, _z, label_contours=True, show_points=True)
 
     Note
@@ -826,6 +828,9 @@ def dumbbell_plot(
             style/color which connects dumbbells.
         show : bool, optional
             whether to show the plot or not
+        ax : plt.Axes, optional
+            matplotlib axes object to work with. If not given then currently available
+            axes will be used.
         **kwargs :
             any additional keyword arguments for `process_axis`.
 
@@ -840,14 +845,14 @@ def dumbbell_plot(
         >>> st = np.random.randint(1, 5, 10)
         >>> en = np.random.randint(11, 20, 10)
         >>> dumbbell_plot(st, en)
-         modify line color
+        ... # modify line color
         >>> dumbbell_plot(st, en, line_kws={'color':"black"})
 
 
     .. _axes.scatter:
         https://matplotlib.org/stable/api/_as_gen/matplotlib.axes.Axes.scatter.html
-
-    .. _axes.scatter:
+    
+    .. _lines.Line2D:
         https://matplotlib.org/stable/api/_as_gen/matplotlib.lines.Line2D.html
 
     """
@@ -968,7 +973,7 @@ def ridge(
 
     ax_objs = []
 
-    for idx, col in enumerate(reversed(ymaxes)):
+    for idx, col in enumerate(reversed(list(ymaxes.keys()))):
 
         # creating new axes object
         ax_objs.append(fig.add_subplot(gs[idx:idx+1, 0:]))
@@ -1080,8 +1085,8 @@ def parallel_coordinates(
     >>> import numpy as np
     >>> import pandas as pd
     >>> from easy_mpl import parallel_coordinates
-    >>> ynames = ['P1', 'P2', 'P3', 'P4', 'P5']
-
+    ...
+    >>> ynames = ['P1', 'P2', 'P3', 'P4', 'P5']  # feature/column names
     >>> N1, N2, N3 = 10, 5, 8
     >>> N = N1 + N2 + N3
     >>> categories_ = ['a', 'b', 'c', 'd', 'e', 'f']
@@ -1090,25 +1095,25 @@ def parallel_coordinates(
     >>> y3 = np.random.binomial(300, 1 / 10, N)
     >>> y4 = np.random.binomial(200, 1 / 3, N)
     >>> y5 = np.random.uniform(0, 800, N)
-    # combine all arrays into a pandas DataFrame
+    ... # combine all arrays into a pandas DataFrame
     >>> data_np = np.column_stack((y1, y2, y3, y4, y5))
     >>> data_df = pd.DataFrame(data_np, columns=ynames)
-    # using a DataFrame to draw parallel coordinates
+    ... # using a DataFrame to draw parallel coordinates
     >>> parallel_coordinates(data_df, names=ynames)
-    # using continuous values for categories
-    >>>parallel_coordinates(data_df, names=ynames, categories=np.random.randint(0, 5, N))
-    # using categorical classes
+    ... # using continuous values for categories
+    >>> parallel_coordinates(data_df, names=ynames, categories=np.random.randint(0, 5, N))
+    ... # using categorical classes
     >>> parallel_coordinates(data_df, names=ynames, categories=random.choices(categories_, k=N))
-    # using numpy array instead of DataFrame
+    ... # using numpy array instead of DataFrame
     >>> parallel_coordinates(data_df.values, names=ynames)
-    with customized tick labels
+    ... # with customized tick labels
     >>> parallel_coordinates(data_df.values, ticklabel_kws={"fontsize": 8, "color": "red"})
-    using straight lines instead of bezier
+    ... # using straight lines instead of bezier
     >>> parallel_coordinates(data_df, linestyle="straight")
-    with categorical class labels
+    ... # with categorical class labels
     >>> data['P5'] = random.choices(categories_, k=N)
     >>> parallel_coordinates(data_df, names=ynames)
-    # with categorical class labels and customized ticklabels
+    ... # with categorical class labels and customized ticklabels
     >>> data['P5'] = random.choices(categories_, k=N)
     >>> parallel_coordinates(data_df,  ticklabel_kws={"fontsize": 8, "color": "red"})
     """
@@ -1274,3 +1279,284 @@ def _rescale(y, _min=0.0, _max=1.0):
 def label_encoder(arr):
     # label encoder of numpy array with categorical values
     return np.unique(arr, return_inverse=True)[1]
+
+
+def lollipop_plot(y, x=None, orientation:str = "vertical", sort:bool =False,
+            line_style:str='-', line_color:str='cyan', line_width:int=1, line_kws: dict=None,
+            marker_style:str='o', marker_color:str='teal', marker_size:int=30, 
+            marker_kws: dict=None, show: bool = True, ax: plt.Axes=None,
+            **kwargs)->plt.Axes:
+    """
+    Plot a lollipop plot.
+
+    Parameters
+    ----------
+    y : array_like, shape (n,), optional
+        The y-coordinates of the data points.
+    x : array_like, shape (n,)
+        The x-coordinates of the data points.
+    orientation : str, optional
+        The orientation of the lollipops. Either "vertical" or "horizontal".
+    sort : bool, optional
+        Whether to sort the data points by their values or not.
+        Only valid if `x` is not specified.
+    line_style : str, optional
+        The line style of the data points.
+    line_color : str, optional
+        The line color of the data points.
+    line_width : float, optional
+        The line width of the data points.
+    line_kws : dict, optional
+        The keyword arguments for the line. These arguments are passed to
+        `matplotlib.axes.Axes.plot`_.
+    marker_style : str, optional
+        The marker style of the data points.
+    marker_color : str, optional
+        The marker color of the data points.
+    marker_size : float, optional
+        The marker size of the data points.
+    marker_kws : dict, optional
+        The keyword arguments for the marker. These arguments are passed to
+        `matplotlib.axes.Axes.scatter`_.
+    ax : matplotlib.axes.Axes, optional
+        The axes to plot on. If not given, current available axes will be used.
+    **kwargs : optional
+        Additional keyword arguments to pass to the process_axis function.
+
+    Returns
+    -------
+    plt.Axes :
+        The axes on which the plot was drawn.
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> from easy_mpl import lollipop_plot
+    >>> y = np.random.randint(0, 10, size=10)
+    ... # vanilla lollipop plot
+    >>> lollipop_plot(y, title="vanilla")
+    ... use both x and y
+    >>> lollipop_plot(y, np.linspace(0, 100, len(y)), title="with x and y")
+    ... # use custom line style
+    >>> lollipop_plot(y, line_style='--', title="with custom linestyle")
+    ... # use custom marker style 
+    >>> lollipop_plot(y, marker_style='D', title="with custom marker style")
+    ... # sort the data points before plotting
+    >>> lollipop_plot(y, sort=True, title="sort")
+    ... # horzontal orientation of lollipops
+    >>> y = np.random.randint(0, 20, size=10)
+    >>> lollipop_plot(y, orientation="horizontal", title="horizontal")
+
+    .. _matplotlib.axes.Axes.plot:
+        https://matplotlib.org/stable/api/_as_gen/matplotlib.axes.Axes.plot.html
+        
+    .. _matplotlib.axes.Axes.scatter:
+        https://matplotlib.org/stable/api/_as_gen/matplotlib.axes.Axes.scatter.html
+    """
+
+    if ax is None:
+        ax = plt.gca()
+    
+    y = to_1d_array(y)
+
+    if sort:
+        idx = np.argsort(y)
+        y = y[idx]
+        assert x is None
+
+    if x is None:
+        x = np.arange(len(y))
+    
+    x = to_1d_array(x)
+    
+    marker_kws = marker_kws or {}
+    line_kws = line_kws or {}
+
+    if orientation == "vertical":
+        _lollipop_vertical(ax, x, y, line_style, line_color, line_width, line_kws,
+                            marker_style, marker_color, marker_size, marker_kws)
+    else:
+        _lollipop_horizontal(ax, x, y, line_style, line_color, line_width, line_kws,
+                            marker_style, marker_color, marker_size, marker_kws)
+    
+    process_axis(ax=ax, **kwargs)
+
+    if show:
+        plt.show()
+    
+    return ax
+
+
+def _lollipop_vertical(ax, x, y, line_style, line_color, line_width, line_kws,
+                       marker_style, marker_color, marker_size, marker_kws):
+    ax.scatter(x, y, marker=marker_style, color=marker_color,
+               s=marker_size, **marker_kws)
+    ax.vlines(x, np.zeros(len(x)), y, color=line_color,
+                          linestyle=line_style, linewidth=line_width, **line_kws)
+    return ax
+
+
+def _lollipop_horizontal(ax, x, y, line_style, line_color, line_width, line_kws,
+                       marker_style, marker_color, marker_size, marker_kws):
+    ax.scatter(y, x, marker=marker_style, color=marker_color,
+               s=marker_size, **marker_kws)
+    ax.hlines(x, np.zeros(len(y)), y, color=line_color,
+                          linestyle=line_style, linewidth=line_width, **line_kws)
+    return ax
+
+
+
+def circular_bar_plot(
+    data, 
+    labels:list=None, 
+    sort=False, 
+    color:Union[str, list, np.ndarray]=None,
+    label_format:str=None,
+    min_max_range: tuple = None,
+    label_padding = 4,
+    figsize:tuple=None, 
+    show=True,
+    **kwargs
+    )->plt.Axes:
+    """
+    Plot a circular bar plot.
+
+    Parameters
+    ----------
+    data : list, np.ndarray, pd.Series
+        Data to plot.
+    labels : list, optional
+        Labels for each data point.
+    sort : bool, optional
+        Sort the data by the values.
+    color : str, list, np.ndarray, optional
+        Color for each data point. It can be a single color or a colormap from 
+        plt.colormaps.
+    label_format : str, optional
+        Format for the labels.
+    min_max_range : tuple, optional
+        Minimum and maximum range for normalizing the data.
+    label_padding : int, optional
+        space between the labels and the bars.
+    figsize : tuple, optional
+        Size of the figure.
+    show : bool, optional
+        Show the plot.
+    **kwargs : optional
+        Additional keyword arguments to pass to the process_axis function.
+
+    Returns
+    -------
+    ax : plt.Axes
+        Axes of the plot.
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> from easy_mpl import circular_bar_plot
+    >>> data = np.random.random(50, )
+    ... # basic
+    >>> circular_bar_plot(data)  
+    ... # with names
+    >>> names = [f"{i}" for i in range(50)]
+    >>> circular_bar_plot(data, names)
+    ... # sort values 
+    >>> circular_bar_plot(data, names, sort=True)
+    ... # custom color map
+    >>> circular_bar_plot(data, names, color='viridis')
+    ... # custom min and max range
+    >>> circular_bar_plot(data, names, min_max_range=(1, 10), label_padding=1)
+    ... # custom label format
+    >>> circular_bar_plot(data, names, label_format='{} {:.4f}')
+
+    """
+
+    plt.close('all')
+    plt.figure(figsize=figsize or (8, 12))
+    ax = plt.subplot(111, polar=True)
+    plt.axis('off')
+
+    if isinstance(data, pd.DataFrame):
+        values = data.values
+    elif isinstance(data, dict):
+        values = np.array(list(data.values()))
+        labels = labels or list(data.keys())
+    else:
+        assert isinstance(data, np.ndarray)
+        values = data
+
+    if labels is None:
+        labels = ['' for _ in range(len(values))]
+        label_format = label_format or "{} {:.2f}"
+    else:
+        label_format = label_format or "{}: {:.2f}"
+
+    if color is None:
+        color = get_cmap(random.choice(BAR_CMAPS), len(values), 0.2)
+    elif isinstance(color, str) and color in plt.colormaps():
+        color = get_cmap(color, len(values), 0.2)
+    else:
+        color = color
+
+    assert len(values) == len(labels)
+
+    min_max_range = min_max_range or (30, 100)
+    lower_limit = min_max_range[0]
+    heights = _rescale(values, lower_limit, min_max_range[1])
+
+    if sort:
+        sort_idx = np.argsort(heights)
+        heights = heights[sort_idx]
+        labels = [labels[i] for i in sort_idx]
+        #color = color[sort_idx]
+
+    # Compute the width of each bar. In total we have 2*Pi = 360°
+    width = 2 * np.pi / len(data)
+
+    # Compute the angle each bar is centered on:
+    indexes = list(range(1, len(data) + 1))
+    angles = [element * width for element in indexes]
+
+    # Draw bars
+    bars = ax.bar(
+        x=angles,
+        height=heights,
+        width=width,
+        bottom=lower_limit,
+        linewidth= 2,
+        edgecolor = "white",
+        color=color,
+    )
+
+    # Add labels
+    for bar, angle, label, val in zip(bars, angles, labels, data):
+
+        label = label_format.format(label, val) 
+
+        # Labels are rotated. Rotation must be specified in degrees :(
+        rotation = np.rad2deg(angle)
+
+        # Flip some labels upside down
+        if angle >= np.pi / 2 and angle < 3 * np.pi / 2:
+            alignment = "right"
+            rotation = rotation + 180
+        else:
+            alignment = "left"
+
+        # Finally add the labels
+        ax.text(
+            x=angle,
+            y=lower_limit + bar.get_height() + label_padding,
+            s=label,
+            ha=alignment,
+            va='center',
+            rotation=rotation,
+            rotation_mode="anchor")
+
+    if kwargs:
+        process_axis(ax, **kwargs)
+
+    if show:    
+        plt.show()
+    
+    return ax
